@@ -4,10 +4,13 @@ try:
 except ImportError:
     def date_range(start=None, end=None, periods=None, freq=None):
         return DatetimeIndex(start, end, periods=periods, offset=freq)
-from pandas.tools.plotting import andrews_curves
+try:
+    from pandas.plotting import andrews_curves
+except ImportError:
+    from pandas.tools.plotting import andrews_curves
 
 
-class plot_timeseries_period(object):
+class TimeseriesPlotting(object):
     goal_time = 0.2
 
     def setup(self):
@@ -17,11 +20,14 @@ class plot_timeseries_period(object):
         self.M = 5
         self.df = DataFrame(np.random.randn(self.N, self.M), index=date_range('1/1/1975', periods=self.N))
 
-    def time_plot_timeseries_period(self):
+    def time_plot_regular(self):
         self.df.plot()
 
+    def time_plot_regular_compat(self):
+        self.df.plot(x_compat=True)
 
-class plot_andrews_curves(object):
+
+class Misc(object):
     goal_time = 0.6
 
     def setup(self):
