@@ -51,13 +51,14 @@ Implementation
 import re
 
 from collections import namedtuple
+from contextlib import contextmanager
 import warnings
 from pandas.compat import map, lmap, u
 import pandas.compat as compat
 
 DeprecatedOption = namedtuple('DeprecatedOption', 'key msg rkey removal_ver')
-RegisteredOption = namedtuple(
-    'RegisteredOption', 'key defval doc validator cb')
+RegisteredOption = namedtuple('RegisteredOption',
+                              'key defval doc validator cb')
 
 _deprecated_options = {}  # holds deprecated option metdata
 _registered_options = {}  # holds registered option metdata
@@ -66,14 +67,14 @@ _reserved_keys = ['all']  # keys which have a special meaning
 
 
 class OptionError(AttributeError, KeyError):
-
     """Exception for pandas.options, backwards compatible with KeyError
-    checks"""
-
+    checks
+    """
 
 #
 # User API
 
+
 def _get_single_key(pat, silent):
     keys = _select_options(pat)
     if len(keys) == 0:
@@ -105,10 +106,14 @@ def _set_option(*args, **kwargs):
     nargs = len(args)
     if not nargs or nargs % 2 != 0:
         raise ValueError("Must provide an even number of non-keyword "
-                             "arguments")
+                         "arguments")
 
     # default to false
-    silent = kwargs.get('silent', False)
+    silent = kwargs.pop('silent', False)
+
+    if kwargs:
+        raise TypeError('_set_option() got an unexpected keyword '
+                        'argument "{0}"'.format(list(kwargs.keys())[0]))
 
     for k, v in zip(args[::2], args[1::2]):
         key = _get_single_key(k, silent)
@@ -122,7 +127,12 @@ def _set_option(*args, **kwargs):
         root[k] = v
 
         if o.cb:
-            o.cb(key)
+            if silent:
+                with warnings.catch_warnings(record=True):
+                    o.cb(key)
+            else:
+                o.cb(key)
+
 
 def _describe_option(pat='', _print_desc=True):
 
@@ -163,9 +173,7 @@ def get_default_val(pat):
 
 
 class DictWrapper(object):
-
-    """ provide attribute-style access to a nested dict
-    """
+    """ provide attribute-style access to a nested dict"""
 
     def __init__(self, d, prefix=""):
         object.__setattr__(self, "d", d)
@@ -197,7 +205,6 @@ class DictWrapper(object):
     def __dir__(self):
         return list(self.d.keys())
 
-
 # For user convenience,  we'd like to have the available options described
 # in the docstring. For dev convenience we'd like to generate the docstrings
 # dynamically instead of maintaining them by hand. To this, we use the
@@ -223,6 +230,7 @@ class CallableDynamicDoc(object):
         return self.__doc_tmpl__.format(opts_desc=opts_desc,
                                         opts_list=opts_list)
 
+
 _get_option_tmpl = """
 get_option(pat)
 
@@ -379,24 +387,21 @@ class option_context(object):
 
     def __init__(self, *args):
         if not (len(args) % 2 == 0 and len(args) >= 2):
-            raise ValueError(
-                'Need to invoke as'
-                'option_context(pat, val, [(pat, val), ...)).'
-            )
+            raise ValueError('Need to invoke as'
+                             'option_context(pat, val, [(pat, val), ...)).')
 
-        ops = list(zip(args[::2], args[1::2]))
+        self.ops = list(zip(args[::2], args[1::2]))
+
+    def __enter__(self):
         undo = []
-        for pat, val in ops:
+        for pat, val in self.ops:
             undo.append((pat, _get_option(pat, silent=True)))
 
         self.undo = undo
 
-        for pat, val in ops:
+        for pat, val in self.ops:
             _set_option(pat, val, silent=True)
 
-    def __enter__(self):
-        pass
-
     def __exit__(self, *args):
         if self.undo:
             for pat, val in self.undo:
@@ -458,8 +463,8 @@ def register_option(key, defval, doc='', validator=None, cb=None):
         cursor = cursor[p]
 
     if not isinstance(cursor, dict):
-        raise OptionError("Path prefix to option '%s' is already an option"
-                          % '.'.join(path[:-1]))
+        raise OptionError("Path prefix to option '%s' is already an option" %
+                          '.'.join(path[:-1]))
 
     cursor[path[-1]] = defval  # initialize
 
@@ -516,10 +521,10 @@ def deprecate_option(key, msg=None, rkey=None, removal_ver=None):
 
     _deprecated_options[key] = DeprecatedOption(key, msg, rkey, removal_ver)
 
-
 #
 # functions internal to the module
 
+
 def _select_options(pat):
     """returns a list of keys matching `pat`
 
@@ -677,12 +682,9 @@ def pp_options_list(keys, width=80, _print=False):
     else:
         return s
 
-
 #
 # helpers
 
-from contextlib import contextmanager
-
 
 @contextmanager
 def config_prefix(prefix):
@@ -715,7 +717,6 @@ def config_prefix(prefix):
     global register_option, get_option, set_option, reset_option
 
     def wrap(func):
-
         def inner(key, *args, **kwds):
             pkey = '%s.%s' % (prefix, key)
             return func(pkey, *args, **kwds)
@@ -733,10 +734,10 @@ def config_prefix(prefix):
     get_option = _get_option
     register_option = _register_option
 
-
 # These factories and methods are handy for use as the validator
 # arg in register_option
 
+
 def is_type_factory(_type):
     """
 
@@ -746,8 +747,8 @@ def is_type_factory(_type):
 
     Returns
     -------
-    validator - a function of a single argument x , which returns the
-                True if type(x) is equal to `_type`
+    validator - a function of a single argument x , which raises
+                ValueError if type(x) is not equal to `_type`
 
     """
 
@@ -767,13 +768,13 @@ def is_instance_factory(_type):
 
     Returns
     -------
-    validator - a function of a single argument x , which returns the
-                True if x is an instance of `_type`
+    validator - a function of a single argument x , which raises
+                ValueError if x is not an instance of `_type`
 
     """
     if isinstance(_type, (tuple, list)):
         _type = tuple(_type)
-        from pandas.core.common import pprint_thing
+        from pandas.io.formats.printing import pprint_thing
         type_repr = "|".join(map(pprint_thing, _type))
     else:
         type_repr = "'%s'" % _type
@@ -786,15 +787,24 @@ def is_instance_factory(_type):
 
 
 def is_one_of_factory(legal_values):
+
+    callables = [c for c in legal_values if callable(c)]
+    legal_values = [c for c in legal_values if not callable(c)]
+
     def inner(x):
-        from pandas.core.common import pprint_thing as pp
-        if not x in legal_values:
-            pp_values = lmap(pp, legal_values)
-            raise ValueError("Value must be one of %s"
-                             % pp("|".join(pp_values)))
+        from pandas.io.formats.printing import pprint_thing as pp
+        if x not in legal_values:
+
+            if not any([c(x) for c in callables]):
+                pp_values = pp("|".join(lmap(pp, legal_values)))
+                msg = "Value must be one of {0}".format(pp_values)
+                if len(callables):
+                    msg += " or a callable"
+                raise ValueError(msg)
 
     return inner
 
+
 # common type validators, for convenience
 # usage: register_option(... , validator = is_int)
 is_int = is_type_factory(int)
@@ -803,3 +813,21 @@ is_float = is_type_factory(float)
 is_str = is_type_factory(str)
 is_unicode = is_type_factory(compat.text_type)
 is_text = is_instance_factory((str, bytes))
+
+
+def is_callable(obj):
+    """
+
+    Parameters
+    ----------
+    `obj` - the object to be checked
+
+    Returns
+    -------
+    validator - returns True if object is callable
+        raises ValueError otherwise.
+
+    """
+    if not callable(obj):
+        raise ValueError("Value must be a callable")
+    return True
